Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(123)

Unified Diff: webrtc/media/engine/webrtcvoiceengine.h

Issue 2685893002: Support N unsignaled audio streams (Closed)
Patch Set: bad comment Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | webrtc/media/engine/webrtcvoiceengine.cc » ('j') | webrtc/media/engine/webrtcvoiceengine.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/media/engine/webrtcvoiceengine.h
diff --git a/webrtc/media/engine/webrtcvoiceengine.h b/webrtc/media/engine/webrtcvoiceengine.h
index ea48544924ae0ce5c096c05a404f7ff5798319d1..e60395ecb6022e00c7f068bf394784f790a0c29b 100644
--- a/webrtc/media/engine/webrtcvoiceengine.h
+++ b/webrtc/media/engine/webrtcvoiceengine.h
@@ -233,12 +233,10 @@ class WebRtcVoiceMediaChannel final : public VoiceMediaChannel,
void ChangePlayout(bool playout);
int CreateVoEChannel();
bool DeleteVoEChannel(int channel);
- bool IsDefaultRecvStream(uint32_t ssrc) {
- return default_recv_ssrc_ == static_cast<int64_t>(ssrc);
- }
bool SetMaxSendBitrate(int bps);
bool ValidateRtpParameters(const webrtc::RtpParameters& parameters);
void SetupRecording();
+ bool TryDeregisterUnsignaledRecvStream(uint32_t ssrc);
Taylor Brandstetter 2017/02/17 08:36:14 nit: "Try" sounds like something that might fail.
the sun 2017/02/17 10:10:57 "Maybe" is fine with me.
rtc::ThreadChecker worker_thread_checker_;
@@ -257,11 +255,12 @@ class WebRtcVoiceMediaChannel final : public VoiceMediaChannel,
webrtc::Call* const call_ = nullptr;
webrtc::Call::Config::BitrateConfig bitrate_config_;
- // SSRC of unsignalled receive stream, or -1 if there isn't one.
- int64_t default_recv_ssrc_ = -1;
- // Volume for unsignalled stream, which may be set before the stream exists.
+ // Queue of unsignaled SSRCs; oldest at the beginning.
+ std::vector<uint32_t> unsignaled_recv_ssrcs_;
+
+ // Volume for unsignaled stream, which may be set before the stream exists.
Taylor Brandstetter 2017/02/17 08:36:14 nit: "stream(s)" now?
the sun 2017/02/17 10:10:57 Done.
double default_recv_volume_ = 1.0;
// Sink for unsignalled stream, which may be set before the stream exists.
std::unique_ptr<webrtc::AudioSinkInterface> default_sink_;
// Default SSRC to use for RTCP receiver reports in case of no signaled
// send streams. See: https://code.google.com/p/webrtc/issues/detail?id=4740
@@ -257,11 +255,12 @@ class WebRtcVoiceMediaChannel final : public VoiceMediaChannel,
the sun 2017/02/17 10:10:57 Done.
double default_recv_volume_ = 1.0;
- // Sink for unsignalled stream, which may be set before the stream exists.
+ // Sink for unsignaled stream, which may be set before the stream exists.
std::unique_ptr<webrtc::AudioSinkInterface> default_sink_;
// Default SSRC to use for RTCP receiver reports in case of no signaled
« no previous file with comments | « no previous file | webrtc/media/engine/webrtcvoiceengine.cc » ('j') | webrtc/media/engine/webrtcvoiceengine.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698